@@ -7,7 +7,7 @@
  * 1999-08-21  V 1.2.0 final
  * 2000-05-31  V 1.3.0 beta
  * 2000-10-04  V 1.3.0 final
- * 2002-01-16  V 1.3.1  
+ * 2002-01-16  V 1.3.1
  * 2003-02-20  V 1.3.2
  * 2010-03-28  V 1.3.4
  * 2019-01-22  V 1.4.1
@@ -43,7 +43,7 @@
 #if defined(__MSDOS__) && !defined(DJGPP)
 #	include "patchlev.h"
 #	include "dosconf.h"
-#   include <alloc.h>
+#	include <alloc.h>
 #	include <conio.h>
 #	include <bios.h>
 #else
@@ -51,21 +51,21 @@
 #	include "config.h"
 #	include <unistd.h>
 #   if defined HAVE_NCURSESW_CURSES_H
-#     include <ncursesw/curses.h>
-#     include <ncursesw/term.h>
+#	include <ncursesw/curses.h>
+#	include <ncursesw/term.h>
 #   elif defined HAVE_NCURSESW_H
-#     include <ncursesw.h>
+#	include <ncursesw.h>
 #   elif defined HAVE_NCURSES_CURSES_H
-#     include <ncurses/curses.h>
+#	include <ncurses/curses.h>
 #   elif defined HAVE_NCURSES_H
-#     include <ncurses.h>
+#	include <ncurses.h>
 #   elif defined HAVE_CURSES_H
-#     include <curses.h>
+#	include <curses.h>
 #   else
-#      error "SysV or X/Open-compatible Curses header file required"
+#	error "SysV or X/Open-compatible Curses header file required"
 #   endif
 #   if HAVE_TERM_H
-#	  include <term.h>
+#	include <term.h>
 #   endif
 #endif
 
@@ -136,7 +136,7 @@ extern	int		no_tty, no_intty;
 
 
 
-#ifdef ANSI
+#if defined(ANSI) || defined(__STDC__)
 	void	initterm(void), set_tty(void), reset_tty(void);
 	void	cleartoeol(void), clearscreen(void), highlight(void);
 	void	normal(void), bmbeep(void), home(void), sig(int);
