@@ -8,16 +8,18 @@
  * 1999-09-10 V 1.2.0 final
  * 2000-03-03 V 1.3.0 beta
  * 2000-07-15 V 1.3.0 final
- * 2001-10-10 V 1.3.1  
+ * 2001-10-10 V 1.3.1
  * 2003-07-04 V 1.3.2
  * 2005-08-17 V 1.3.3
  * 2010-06-02 V 1.3.4
  * 2014-01-28 V 1.4.0
  * 2019-01-27 V 1.4.1
+ * 2023-03-06 V 1.4.2
+ * 2025-07-19 V 1.5.0
  *
  * NOTE: Edit this file with tabstop=4 !
  *
- * Copyright 1996-2019 by Gerhard Buergmann
+ * Copyright 1996-2025 by Gerhard Buergmann
  * gerhard@puon.at
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -71,8 +73,8 @@ static	char	*c_argv[9];
 
 char	*nowrtmsg  = "No write@since last change (:%s! overrides)";
 char	*morefiles = "more files@to edit";
-char	*ambigous  = "Ambigous|Too many file names";
-char	*ambvalue  = "Ambigous|Too many values";
+char	*ambigous  = "Ambiguous|Too many file names";
+char	*ambvalue  = "Ambiguous|Too many values";
 char	*extra     = "Extra chars|Extra characters at end of command";
 char	*noaddr    = "No address allowed@on this command";
 char	*noval     = "No value@for binary operation";
@@ -87,7 +89,7 @@ extern	char	**files;		/* used for "next" and "rewind" */
 extern	int		numfiles, curfile;
 extern	int		errno;
 
-static	char	oldbuf[CMDSZ];		/** for :!! command **/
+static	char	oldbuf[CMDSZ + 3];		/** for :!! command **/
 
 
 /*
@@ -97,8 +99,7 @@ static	char	oldbuf[CMDSZ];		/** for :!! command **/
  * the environment variable "BVIINIT" (or eventually .bvirc).
  */
 void
-docmdline(cmdline)
-	char	*cmdline;
+docmdline(char *cmdline)
 {
 	char	buff[CMDSZ];
 	char	cmdbuf[CMDSZ];
@@ -285,22 +286,22 @@ docmdline(cmdline)
 		if ((c_argv[c_argc] = strtok(cmd, " \t")) != NULL) c_argc++;
 		while ((c_argv[c_argc] = strtok(NULL, " \t")) != NULL) c_argc++;
 
-		if (c_argc > 1) { 
+		if (c_argc > 1) {
 			emsg(ambigous);
 			return; }
 		if (c_argc == 1) {
-		    /* change '%' to Filename */
-		    while ((p = strchr(c_argv[0], '%')) != NULL && *(p-1) != '\\') {
-		        if (name == NULL) {
-		            emsg("No filename@to substitute for %");
-		            return;
-		        }
-		        *p = '\0';
-		        strcpy (oldbuf, c_argv[0]);
-		        strcat (oldbuf, name);
-		        strcat (oldbuf, p + 1);
+			/* change '%' to Filename */
+			while ((p = strchr(c_argv[0], '%')) != NULL && *(p-1) != '\\') {
+				if (name == NULL) {
+					emsg("No filename@to substitute for %");
+					return;
+				}
+				*p = '\0';
+				strcpy (oldbuf, c_argv[0]);
+				strcat (oldbuf, name);
+				strcat (oldbuf, p + 1);
 				c_argv[0] = oldbuf;
-		    }
+			}
 		}
 		if (name == NULL && c_argc != 0) name = strdup(c_argv[0]);
 		if (force) {
@@ -308,7 +309,7 @@ docmdline(cmdline)
 				else	ok = save(c_argv[0], start_addr, end_addr, saveflag);
 		} else {
 			if (c_argc == 0) {
-				save_chk(name, start_addr, end_addr, saveflag);
+				ok = save_chk(name, start_addr, end_addr, saveflag);
 			} else {
 				if (!stat(c_argv[0], &buf)) {
 					if (saveflag == WRITE) {
@@ -628,11 +629,7 @@ yd_addr()
 
 /*********** Save file if not read only ********************/
 int
-save_chk(fname, start, end, flags)
-   char    *fname;
-   char    *start;
-   char    *end;
-   int     flags;
+save_chk(char *fname, char *start, char *end, int flags)
 {
    if (P(P_RO)) {
        sprintf(string, "\"%s\" File is read only", name);
@@ -656,9 +653,7 @@ do_exit()
 
 
 int
-doecmd(arg, force)
-	char	*arg;
-	int		force;
+doecmd(char *arg, int force)
 {
 	char *tmp;
 
@@ -721,33 +716,34 @@ clearstr()
 
 /**** displays an error message *****/
 void
-emsg(s)
-	char	*s;
+emsg(char *s)
 {
 	int	cnt;
-	int stchar;
+	/*
+	int	stchar;
 
-	if (P(P_EB)) beep();
 	if (P(P_MO)) {
 		stchar = statsize;
 	} else {
 		stchar = 0;
 	}
-
+	*/
+	if (P(P_EB)) beep();
+	statusflag = 0;
 	clearstr();
 	attrset(A_REVERSE);
 	cnt = outmsg(s);
 	attrset(A_NORMAL);
-	if (cnt >= (maxx - stchar)) {
-		addch('\n');
-		wait_return(TRUE); }
+	if (cnt >= (maxx)) {
+		// addch('\n');
+		wait_return(TRUE);
+	}
 }
 
 
 /*** System error message *****/
 void
-sysemsg(s)
-	char	*s;
+sysemsg(char *s)
 {
 	char	string[256];
 
@@ -763,8 +759,7 @@ sysemsg(s)
 
 /*** displays mode if showmode set *****/
 void
-smsg(s)
-	char	*s;
+smsg(char *s)
 {
 	if (P(P_MO)) {
 		msg(s);
@@ -775,30 +770,30 @@ smsg(s)
 
 /************* displays s on status line *****************/
 void
-msg(s)
-	char	*s;
+msg(char *s)
 {
+	/*
 	int stchar;
 
 	if (P(P_MO)) {
 		stchar = statsize;
 	} else {
 		stchar = 0;
-	}
+	}o*/
+	statusflag = 0;
 	clearstr();
-	if (outmsg(s) >= (maxx - stchar)) {
-		addch('\n');
+	if (outmsg(s) >= maxx) {
+		// addch('\n');
 		wait_return(TRUE);
 	}
 }
 
 
 int
-outmsg(s)
-	char	*s;
+outmsg(char *s)
 {
 	char	*poi;
-	int		cnt = 0;
+	int	cnt = 0;
 
 	move(maxy, 0);
 	poi = strchr(s, '|');
@@ -810,7 +805,7 @@ outmsg(s)
 			cnt++;
 		}
 	} else {
-    	if (poi) poi++;
+    		if (poi) poi++;
 			else poi = s;
 		while (*poi) {
 			if (*poi == '@') addch(' ');
@@ -827,8 +822,7 @@ outmsg(s)
  *
  */
 int
-wait_return(flag)
-	int	flag;
+wait_return(int flag)
 {
 	int	c;
 
@@ -851,8 +845,7 @@ wait_return(flag)
 
 
 int
-chk_comm(flag)
-	int flag;
+chk_comm(int flag)
 {
 	if ((flag & NO_ADDR) && (addr_flag > 0)) {
 		emsg(noaddr); return 1; }
